Class: SimpleActivity::Rule
- Inherits:
-
Object
- Object
- SimpleActivity::Rule
- Defined in:
- lib/simple_activity/rule.rb
Class Method Summary collapse
-
.get_rules(target_type, rules_set = nil) ⇒ Object
Get a set of rules for specific target, action, and type.
Class Method Details
.get_rules(target_type, rules_set = nil) ⇒ Object
Get a set of rules for specific target, action, and type. The type is normally “cache”. It can also be other things once needed in external libs.
-
get all rules.
14 15 16 17 |
# File 'lib/simple_activity/rule.rb', line 14 def self.get_rules(target_type, rules_set=nil) rules = all_rules.try(:[], target_type) rules_set ? rules.try(:[], rules_set) : rules end |